using System;
using UnityEngine;
using System.Collections;
using System.Collections.Generic;
using SimpleJSON;
using System.Linq;

/// <summary>
/// Settings: Delete Scenes and Appearances
/// </summary>
namespace MVRPlugin 
{
    public class SettingsDeleteScenes : MVRScript
    {
		public  bool              optionBackupPackages            = false;
		public  bool              optionBackupAppearances         = false;

		public  JSONStorableBool  jsonOptionBackupPackages        = null;		
		public  JSONStorableBool  jsonOptionBackupAppearances     = null;
		
		private UIDynamicToggle   onToggleOptionBackupPackages    = null;		
		private UIDynamicToggle   onToggleOptionBackupAppearances = null;
		
		
        public override void Init()
        {
            try
            {
				if (containingAtom.type != "CoreControl" && containingAtom.type != "SessionPluginManager")
                {
                    SuperController.LogError($"Please load Delete Scenes and Appearances as a Session or Scene Plugin, not with a '{containingAtom.type}' atom.");
                    DestroyImmediate(this);
                    return;
                }
				
				// Set up Custom UI
				SetupInfoText(this, "<color=#606060><size=40><b>Settings: Delete Scenes and Appearances</b></size></color>", 20.0f, false);
				
				// Save notification
				SetupInfoText(this,
                    "<color=#606060><size=40><b>Saving Settings</b></size>\n"              +
                    "To permanently save the settings below when restarting Virt-a-Mate, " +
                    "make sure to choose 'Session Plugin Presets -> Change User Defaults -> Set Current As User Defaults'.</color>\n\n",
                    270.0f, false
                );
				
				// Warning text
				SetupInfoText(this, "<color=#606060><size=30>Packages will be backed up from: AddonPackages\nto:\nAddonPackagesDeleted</size></color>", 150.0f, false);
				SetupInfoText(this, "<color=#606060><size=30>Saved Appearances will be backed up from:\nSaves\\Person\\appearance\nto:\nAddonPackagesDeleted\\\nAppearances</size></color>", 220.0f, false);
				SetupInfoText(this, "<color=#606060><size=30>Appearances within packages will not be backed up.</size></color>", 60.0f, false);
				
				// Toggle: Prompt
                jsonOptionBackupPackages = new JSONStorableBool("Backup Packages", optionBackupPackages);
                RegisterBool(jsonOptionBackupPackages);
                onToggleOptionBackupPackages = CreateToggle(jsonOptionBackupPackages, false);
                onToggleOptionBackupPackages.toggle.onValueChanged.AddListener((on) => { ToggleOptionBackupPackages(on); });
				
				// Toggle: Automatically Allow
                jsonOptionBackupAppearances = new JSONStorableBool("Backup Appearances", optionBackupAppearances);
                RegisterBool(jsonOptionBackupAppearances);
                onToggleOptionBackupAppearances = CreateToggle(jsonOptionBackupAppearances, false);
                onToggleOptionBackupAppearances.toggle.onValueChanged.AddListener((on) => { ToggleOptionBackupAppearances(on); });
            }
            catch (Exception e)
            { SuperController.LogError("Failed to initialize plugin: " + e); }
        }
		
		public bool GetOptionBackupPackages()
		{ return optionBackupPackages; }
		
		public bool GetOptionBackupAppearances()
		{ return optionBackupAppearances; }
		
		public void UpdateSettings(bool BackupPackages, bool BackupAppearances)
		{
			optionBackupPackages                        = BackupPackages;
			optionBackupAppearances                     = BackupAppearances;

			jsonOptionBackupPackages.val                = BackupPackages;
			jsonOptionBackupAppearances.val             = BackupAppearances;
			
			onToggleOptionBackupPackages.toggle.isOn    = BackupPackages;
			onToggleOptionBackupAppearances.toggle.isOn = BackupAppearances;
		}
		
		public void ToggleOptionBackupPackages(bool ToggleState)
        { optionBackupPackages = ToggleState; }
		
		public void ToggleOptionBackupAppearances(bool ToggleState)
        { optionBackupAppearances = ToggleState; }
		
		private static JSONStorableString SetupInfoText(MVRScript script, string text, float height, bool rightSide)
        {
            JSONStorableString storable = new JSONStorableString("Info", text);
            UIDynamic textfield = script.CreateTextField(storable, rightSide);
            textfield.height = height;
            return storable;
        }

    }
}
